@@ -1,6 +1,6 @@
 #' @rdname file_connections
 #' @export
-file_read <- function(file, mode = "r", filter = NULL, options = character()) {
+file_read <- function(file, mode = "r", filter = NULL, options = character(), password = NA_character_) {
   options <- validate_options(options)
 
   if (!inherits(archive, "connection")) {
@@ -9,5 +9,5 @@ file_read <- function(file, mode = "r", filter = NULL, options = character()) {
 
   description <- glue::glue("file_read({desc})", desc = summary(file)$description)
 
-  archive_read_(file, 1L, description, mode, archive_formats()["raw"], archive_filters()[filter], options, sz = 2^14)
+  archive_read_(file, 1L, description, mode, archive_formats()["raw"], archive_filters()[filter], options, c(password), sz = 2^14)
 }
