@@ -98,6 +98,7 @@ static const char* strip_components(const char* p, int elements) {
     cpp11::sexp file,
     int num_strip_components,
     cpp11::strings options,
+    cpp11::strings password,
     size_t sz = 16384) {
   struct archive* a;
   struct archive* ext;
@@ -125,6 +126,10 @@ static const char* strip_components(const char* p, int elements) {
     call(archive_read_set_options, a, std::string(options[0]).c_str());
   }
 
+  if (!cpp11::is_na(password[0])) {
+    call(archive_read_add_passphrase, a, std::string(password[0]).c_str());
+  }
+
   call(archive_read_set_read_callback, a, input_read);
   call(archive_read_set_close_callback, a, input_close);
   static auto isSeekable = cpp11::package("base")["isSeekable"];
