@@ -108,6 +108,10 @@ static Rboolean rchive_read_open(Rconnection con) {
     call(archive_read_set_options, con, r->options.c_str());
   }
 
+  if (!cpp11::is_na(r->password[0])) {
+    call(archive_read_add_passphrase, con, std::string(r->password[0]).c_str());
+  }
+
   static auto open = cpp11::package("base")["open"];
   static auto isOpen = cpp11::package("base")["isOpen"];
   if (!isOpen(r->input.connection)) {
@@ -202,6 +206,7 @@ static int rchive_fgetc(Rconnection con) {
     cpp11::integers format,
     cpp11::integers filters,
     cpp11::strings options,
+    cpp11::strings password,
     size_t sz = 16384) {
   Rconnection con;
 
@@ -222,6 +227,7 @@ static int rchive_fgetc(Rconnection con) {
   }
 
   r->format = format.size() == 0 ? -1 : format[0];
+  r->password = password;
 
   /* Initialize filters */
   if (filters.size() > FILTER_MAX) {
