@@ -28,6 +28,10 @@ static Rboolean rchive_write_direct_open(Rconnection con) {
 
   call(archive_write_set_format, con, r->format);
 
+  if (!cpp11::is_na(r->password[0])) {
+    call(archive_write_set_passphrase, con, std::string(r->password[0]).c_str());
+  }
+
   if (!r->options.empty()) {
     call(archive_write_set_options, con, r->options.c_str());
   }
@@ -80,6 +84,7 @@ void rchive_write_direct_destroy(Rconnection con) {
     int format,
     cpp11::integers filters,
     cpp11::strings options,
+    cpp11::strings password,
     size_t sz) {
   Rconnection con;
   SEXP rc =
@@ -102,6 +107,7 @@ void rchive_write_direct_destroy(Rconnection con) {
   }
 
   r->format = format;
+  r->password = password;
 
   r->filename = std::move(filename);
 
